"use strict";
/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
Object.defineProperty(exports, "__esModule", { value: true });
const os = require("os");
const command_1 = require("@salesforce/command");
const core_1 = require("@salesforce/core");
const dataCommand_1 = require("../../../../dataCommand");
core_1.Messages.importMessagesDirectory(__dirname);
const messages = core_1.Messages.loadMessages('@salesforce/plugin-data', 'record.update');
const commonMessages = core_1.Messages.loadMessages('@salesforce/plugin-data', 'messages');
class Update extends dataCommand_1.DataCommand {
    async run() {
        this.validateIdXorWhereFlags();
        this.ux.startSpinner('Updating Record');
        let status = 'Success';
        const sobject = this.getConnection().sobject(this.flags.sobjecttype);
        const sObjectId = (this.flags.sobjectid || (await this.query(sobject, this.flags.where)).Id);
        try {
            const updateObject = this.stringToDictionary(this.flags.values);
            updateObject.Id = sObjectId;
            // eslint-disable-next-line @typescript-eslint/ban-ts-comment
            // @ts-ignore
            const result = await sobject.update(updateObject);
            if (result.success) {
                this.ux.log(messages.getMessage('updateSuccess', [sObjectId]));
            }
            else {
                const errors = this.collectErrorMessages(result);
                this.ux.error(messages.getMessage('updateFailure', [errors]));
            }
            this.ux.stopSpinner(status);
            return result;
        }
        catch (err) {
            status = 'Failed';
            this.ux.stopSpinner(status);
            const error = err;
            if (Reflect.has(error, 'errorCode') && Reflect.has(error, 'fields')) {
                throw new core_1.SfError(messages.getMessage('updateFailureWithFields', [
                    Reflect.get(error, 'errorCode'),
                    Reflect.get(error, 'message'),
                    Reflect.get(error, 'fields'),
                ]));
            }
            else {
                throw err;
            }
        }
    }
}
exports.default = Update;
Update.description = messages.getMessage('description');
Update.examples = messages.getMessage('examples').split(os.EOL);
Update.requiresUsername = true;
Update.flagsConfig = {
    sobjecttype: command_1.flags.string({
        char: 's',
        required: true,
        description: messages.getMessage('sObjectType'),
    }),
    sobjectid: command_1.flags.id({
        char: 'i',
        description: messages.getMessage('sObjectId'),
        exclusive: ['where'],
    }),
    where: command_1.flags.string({
        char: 'w',
        description: messages.getMessage('where'),
        exclusive: ['sobjectid'],
    }),
    values: command_1.flags.string({
        char: 'v',
        required: true,
        description: messages.getMessage('values'),
    }),
    usetoolingapi: command_1.flags.boolean({
        char: 't',
        description: messages.getMessage('useToolingApi'),
    }),
    perflog: command_1.flags.boolean({
        description: commonMessages.getMessage('perfLogLevelOption'),
        dependsOn: ['json'],
    }),
};
//# sourceMappingURL=update.js.map